
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import device_attributes_pb2 as tensorflow_dot_core_dot_framework_dot_device__attributes__pb2
from ....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.protobuf import config_pb2 as tensorflow_dot_core_dot_protobuf_dot_config__pb2
from ....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
from ....tensorflow.core.protobuf import named_tensor_pb2 as tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/master.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x1aorg.tensorflow.distruntimeB\x18DistributedRuntimeProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/protobuf/master.proto\x12\ntensorflow\x1a1tensorflow/core/framework/device_attributes.proto\x1a%tensorflow/core/framework/graph.proto\x1a&tensorflow/core/framework/tensor.proto\x1a%tensorflow/core/protobuf/config.proto\x1a*tensorflow/core/protobuf/error_codes.proto\x1a+tensorflow/core/protobuf/named_tensor.proto"x\n\x14CreateSessionRequest\x12\'\n\tgraph_def\x18\x01 \x01(\x0b2\x14.tensorflow.GraphDef\x12\'\n\x06config\x18\x02 \x01(\x0b2\x17.tensorflow.ConfigProto\x12\x0e\n\x06target\x18\x03 \x01(\t"F\n\x15CreateSessionResponse\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x15\n\rgraph_version\x18\x02 \x01(\x03"v\n\x14ExtendSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\'\n\tgraph_def\x18\x02 \x01(\x0b2\x14.tensorflow.GraphDef\x12\x1d\n\x15current_graph_version\x18\x03 \x01(\x03"2\n\x15ExtendSessionResponse\x12\x19\n\x11new_graph_version\x18\x04 \x01(\x03"\xf3\x01\n\x0eRunStepRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12*\n\x04feed\x18\x02 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12\r\n\x05fetch\x18\x03 \x03(\t\x12\x0e\n\x06target\x18\x04 \x03(\t\x12\'\n\x07options\x18\x05 \x01(\x0b2\x16.tensorflow.RunOptions\x12\x1a\n\x12partial_run_handle\x18\x06 \x01(\t\x12%\n\x1dstore_errors_in_response_body\x18\x07 \x01(\x08\x12\x12\n\nrequest_id\x18\x08 \x01(\x03"\xb5\x01\n\x0fRunStepResponse\x12,\n\x06tensor\x18\x01 \x03(\x0b2\x1c.tensorflow.NamedTensorProto\x12)\n\x08metadata\x18\x02 \x01(\x0b2\x17.tensorflow.RunMetadata\x12+\n\x0bstatus_code\x18\x03 \x01(\x0e2\x16.tensorflow.error.Code\x12\x1c\n\x14status_error_message\x18\x04 \x01(\t"q\n\x16PartialRunSetupRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0c\n\x04feed\x18\x02 \x03(\t\x12\r\n\x05fetch\x18\x03 \x03(\t\x12\x0e\n\x06target\x18\x04 \x03(\t\x12\x12\n\nrequest_id\x18\x05 \x01(\x03"5\n\x17PartialRunSetupResponse\x12\x1a\n\x12partial_run_handle\x18\x01 \x01(\t"-\n\x13CloseSessionRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t"\x16\n\x14CloseSessionResponse"9\n\x0cResetRequest\x12\x11\n\tcontainer\x18\x01 \x03(\t\x12\x16\n\x0edevice_filters\x18\x02 \x03(\t"\x0f\n\rResetResponse",\n\x12ListDevicesRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t"~\n\x13ListDevicesResponse\x122\n\x0clocal_device\x18\x01 \x03(\x0b2\x1c.tensorflow.DeviceAttributes\x123\n\rremote_device\x18\x02 \x03(\x0b2\x1c.tensorflow.DeviceAttributes"o\n\x13MakeCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12,\n\x07options\x18\x02 \x01(\x0b2\x1b.tensorflow.CallableOptions\x12\x12\n\nrequest_id\x18\x03 \x01(\x03"&\n\x14MakeCallableResponse\x12\x0e\n\x06handle\x18\x01 \x01(\x03"w\n\x12RunCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x03\x12%\n\x04feed\x18\x03 \x03(\x0b2\x17.tensorflow.TensorProto\x12\x12\n\nrequest_id\x18\x04 \x01(\x03"h\n\x13RunCallableResponse\x12&\n\x05fetch\x18\x01 \x03(\x0b2\x17.tensorflow.TensorProto\x12)\n\x08metadata\x18\x02 \x01(\x0b2\x17.tensorflow.RunMetadata"@\n\x16ReleaseCallableRequest\x12\x16\n\x0esession_handle\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x03"\x19\n\x17ReleaseCallableResponseB\x92\x01\n\x1aorg.tensorflow.distruntimeB\x18DistributedRuntimeProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_device__attributes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_config__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2.DESCRIPTOR])
_CREATESESSIONREQUEST = _descriptor.Descriptor(name='CreateSessionRequest', full_name='tensorflow.CreateSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.CreateSessionRequest.graph_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='config', full_name='tensorflow.CreateSessionRequest.config', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.CreateSessionRequest.target', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=311, serialized_end=431)
_CREATESESSIONRESPONSE = _descriptor.Descriptor(name='CreateSessionResponse', full_name='tensorflow.CreateSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.CreateSessionResponse.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_version', full_name='tensorflow.CreateSessionResponse.graph_version', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=433, serialized_end=503)
_EXTENDSESSIONREQUEST = _descriptor.Descriptor(name='ExtendSessionRequest', full_name='tensorflow.ExtendSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ExtendSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_def', full_name='tensorflow.ExtendSessionRequest.graph_def', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_graph_version', full_name='tensorflow.ExtendSessionRequest.current_graph_version', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=505, serialized_end=623)
_EXTENDSESSIONRESPONSE = _descriptor.Descriptor(name='ExtendSessionResponse', full_name='tensorflow.ExtendSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='new_graph_version', full_name='tensorflow.ExtendSessionResponse.new_graph_version', index=0, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=625, serialized_end=675)
_RUNSTEPREQUEST = _descriptor.Descriptor(name='RunStepRequest', full_name='tensorflow.RunStepRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RunStepRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.RunStepRequest.feed', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.RunStepRequest.fetch', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.RunStepRequest.target', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='options', full_name='tensorflow.RunStepRequest.options', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='partial_run_handle', full_name='tensorflow.RunStepRequest.partial_run_handle', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='store_errors_in_response_body', full_name='tensorflow.RunStepRequest.store_errors_in_response_body', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RunStepRequest.request_id', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=678, serialized_end=921)
_RUNSTEPRESPONSE = _descriptor.Descriptor(name='RunStepResponse', full_name='tensorflow.RunStepResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.RunStepResponse.tensor', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.RunStepResponse.metadata', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_code', full_name='tensorflow.RunStepResponse.status_code', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='status_error_message', full_name='tensorflow.RunStepResponse.status_error_message', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=924, serialized_end=1105)
_PARTIALRUNSETUPREQUEST = _descriptor.Descriptor(name='PartialRunSetupRequest', full_name='tensorflow.PartialRunSetupRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.PartialRunSetupRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.PartialRunSetupRequest.feed', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.PartialRunSetupRequest.fetch', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='target', full_name='tensorflow.PartialRunSetupRequest.target', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.PartialRunSetupRequest.request_id', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1107, serialized_end=1220)
_PARTIALRUNSETUPRESPONSE = _descriptor.Descriptor(name='PartialRunSetupResponse', full_name='tensorflow.PartialRunSetupResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='partial_run_handle', full_name='tensorflow.PartialRunSetupResponse.partial_run_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1222, serialized_end=1275)
_CLOSESESSIONREQUEST = _descriptor.Descriptor(name='CloseSessionRequest', full_name='tensorflow.CloseSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.CloseSessionRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1277, serialized_end=1322)
_CLOSESESSIONRESPONSE = _descriptor.Descriptor(name='CloseSessionResponse', full_name='tensorflow.CloseSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1324, serialized_end=1346)
_RESETREQUEST = _descriptor.Descriptor(name='ResetRequest', full_name='tensorflow.ResetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='container', full_name='tensorflow.ResetRequest.container', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_filters', full_name='tensorflow.ResetRequest.device_filters', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1348, serialized_end=1405)
_RESETRESPONSE = _descriptor.Descriptor(name='ResetResponse', full_name='tensorflow.ResetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1407, serialized_end=1422)
_LISTDEVICESREQUEST = _descriptor.Descriptor(name='ListDevicesRequest', full_name='tensorflow.ListDevicesRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ListDevicesRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1424, serialized_end=1468)
_LISTDEVICESRESPONSE = _descriptor.Descriptor(name='ListDevicesResponse', full_name='tensorflow.ListDevicesResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='local_device', full_name='tensorflow.ListDevicesResponse.local_device', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remote_device', full_name='tensorflow.ListDevicesResponse.remote_device', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1470, serialized_end=1596)
_MAKECALLABLEREQUEST = _descriptor.Descriptor(name='MakeCallableRequest', full_name='tensorflow.MakeCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.MakeCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='options', full_name='tensorflow.MakeCallableRequest.options', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.MakeCallableRequest.request_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1598, serialized_end=1709)
_MAKECALLABLERESPONSE = _descriptor.Descriptor(name='MakeCallableResponse', full_name='tensorflow.MakeCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='handle', full_name='tensorflow.MakeCallableResponse.handle', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1711, serialized_end=1749)
_RUNCALLABLEREQUEST = _descriptor.Descriptor(name='RunCallableRequest', full_name='tensorflow.RunCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.RunCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle', full_name='tensorflow.RunCallableRequest.handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='feed', full_name='tensorflow.RunCallableRequest.feed', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='request_id', full_name='tensorflow.RunCallableRequest.request_id', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1751, serialized_end=1870)
_RUNCALLABLERESPONSE = _descriptor.Descriptor(name='RunCallableResponse', full_name='tensorflow.RunCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='fetch', full_name='tensorflow.RunCallableResponse.fetch', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.RunCallableResponse.metadata', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1872, serialized_end=1976)
_RELEASECALLABLEREQUEST = _descriptor.Descriptor(name='ReleaseCallableRequest', full_name='tensorflow.ReleaseCallableRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.ReleaseCallableRequest.session_handle', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle', full_name='tensorflow.ReleaseCallableRequest.handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1978, serialized_end=2042)
_RELEASECALLABLERESPONSE = _descriptor.Descriptor(name='ReleaseCallableResponse', full_name='tensorflow.ReleaseCallableResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2044, serialized_end=2069)
_CREATESESSIONREQUEST.fields_by_name['graph_def'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_CREATESESSIONREQUEST.fields_by_name['config'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._CONFIGPROTO
_EXTENDSESSIONREQUEST.fields_by_name['graph_def'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_RUNSTEPREQUEST.fields_by_name['feed'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNSTEPREQUEST.fields_by_name['options'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNOPTIONS
_RUNSTEPRESPONSE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_protobuf_dot_named__tensor__pb2._NAMEDTENSORPROTO
_RUNSTEPRESPONSE.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNMETADATA
_RUNSTEPRESPONSE.fields_by_name['status_code'].enum_type = tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2._CODE
_LISTDEVICESRESPONSE.fields_by_name['local_device'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_LISTDEVICESRESPONSE.fields_by_name['remote_device'].message_type = tensorflow_dot_core_dot_framework_dot_device__attributes__pb2._DEVICEATTRIBUTES
_MAKECALLABLEREQUEST.fields_by_name['options'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._CALLABLEOPTIONS
_RUNCALLABLEREQUEST.fields_by_name['feed'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_RUNCALLABLERESPONSE.fields_by_name['fetch'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_RUNCALLABLERESPONSE.fields_by_name['metadata'].message_type = tensorflow_dot_core_dot_protobuf_dot_config__pb2._RUNMETADATA
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtendSessionRequest'] = _EXTENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['ExtendSessionResponse'] = _EXTENDSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['RunStepRequest'] = _RUNSTEPREQUEST
DESCRIPTOR.message_types_by_name['RunStepResponse'] = _RUNSTEPRESPONSE
DESCRIPTOR.message_types_by_name['PartialRunSetupRequest'] = _PARTIALRUNSETUPREQUEST
DESCRIPTOR.message_types_by_name['PartialRunSetupResponse'] = _PARTIALRUNSETUPRESPONSE
DESCRIPTOR.message_types_by_name['CloseSessionRequest'] = _CLOSESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CloseSessionResponse'] = _CLOSESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ResetResponse'] = _RESETRESPONSE
DESCRIPTOR.message_types_by_name['ListDevicesRequest'] = _LISTDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ListDevicesResponse'] = _LISTDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['MakeCallableRequest'] = _MAKECALLABLEREQUEST
DESCRIPTOR.message_types_by_name['MakeCallableResponse'] = _MAKECALLABLERESPONSE
DESCRIPTOR.message_types_by_name['RunCallableRequest'] = _RUNCALLABLEREQUEST
DESCRIPTOR.message_types_by_name['RunCallableResponse'] = _RUNCALLABLERESPONSE
DESCRIPTOR.message_types_by_name['ReleaseCallableRequest'] = _RELEASECALLABLEREQUEST
DESCRIPTOR.message_types_by_name['ReleaseCallableResponse'] = _RELEASECALLABLERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CreateSessionRequest = _reflection.GeneratedProtocolMessageType('CreateSessionRequest', (_message.Message,), {'DESCRIPTOR': _CREATESESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CreateSessionRequest)
CreateSessionResponse = _reflection.GeneratedProtocolMessageType('CreateSessionResponse', (_message.Message,), {'DESCRIPTOR': _CREATESESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CreateSessionResponse)
ExtendSessionRequest = _reflection.GeneratedProtocolMessageType('ExtendSessionRequest', (_message.Message,), {'DESCRIPTOR': _EXTENDSESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ExtendSessionRequest)
ExtendSessionResponse = _reflection.GeneratedProtocolMessageType('ExtendSessionResponse', (_message.Message,), {'DESCRIPTOR': _EXTENDSESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ExtendSessionResponse)
RunStepRequest = _reflection.GeneratedProtocolMessageType('RunStepRequest', (_message.Message,), {'DESCRIPTOR': _RUNSTEPREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunStepRequest)
RunStepResponse = _reflection.GeneratedProtocolMessageType('RunStepResponse', (_message.Message,), {'DESCRIPTOR': _RUNSTEPRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunStepResponse)
PartialRunSetupRequest = _reflection.GeneratedProtocolMessageType('PartialRunSetupRequest', (_message.Message,), {'DESCRIPTOR': _PARTIALRUNSETUPREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(PartialRunSetupRequest)
PartialRunSetupResponse = _reflection.GeneratedProtocolMessageType('PartialRunSetupResponse', (_message.Message,), {'DESCRIPTOR': _PARTIALRUNSETUPRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(PartialRunSetupResponse)
CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {'DESCRIPTOR': _CLOSESESSIONREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CloseSessionRequest)
CloseSessionResponse = _reflection.GeneratedProtocolMessageType('CloseSessionResponse', (_message.Message,), {'DESCRIPTOR': _CLOSESESSIONRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(CloseSessionResponse)
ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {'DESCRIPTOR': _RESETREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ResetRequest)
ResetResponse = _reflection.GeneratedProtocolMessageType('ResetResponse', (_message.Message,), {'DESCRIPTOR': _RESETRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ResetResponse)
ListDevicesRequest = _reflection.GeneratedProtocolMessageType('ListDevicesRequest', (_message.Message,), {'DESCRIPTOR': _LISTDEVICESREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ListDevicesRequest)
ListDevicesResponse = _reflection.GeneratedProtocolMessageType('ListDevicesResponse', (_message.Message,), {'DESCRIPTOR': _LISTDEVICESRESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ListDevicesResponse)
MakeCallableRequest = _reflection.GeneratedProtocolMessageType('MakeCallableRequest', (_message.Message,), {'DESCRIPTOR': _MAKECALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(MakeCallableRequest)
MakeCallableResponse = _reflection.GeneratedProtocolMessageType('MakeCallableResponse', (_message.Message,), {'DESCRIPTOR': _MAKECALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(MakeCallableResponse)
RunCallableRequest = _reflection.GeneratedProtocolMessageType('RunCallableRequest', (_message.Message,), {'DESCRIPTOR': _RUNCALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunCallableRequest)
RunCallableResponse = _reflection.GeneratedProtocolMessageType('RunCallableResponse', (_message.Message,), {'DESCRIPTOR': _RUNCALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(RunCallableResponse)
ReleaseCallableRequest = _reflection.GeneratedProtocolMessageType('ReleaseCallableRequest', (_message.Message,), {'DESCRIPTOR': _RELEASECALLABLEREQUEST, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ReleaseCallableRequest)
ReleaseCallableResponse = _reflection.GeneratedProtocolMessageType('ReleaseCallableResponse', (_message.Message,), {'DESCRIPTOR': _RELEASECALLABLERESPONSE, '__module__': 'tensorflow.core.protobuf.master_pb2'})
_sym_db.RegisterMessage(ReleaseCallableResponse)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/model.proto', package='tensorflow.data.model', syntax='proto3', serialized_options=b'ZLgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/model_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/framework/model.proto\x12\x15tensorflow.data.model"\x8e\x08\n\nModelProto\x12;\n\x05nodes\x18\x01 \x03(\x0b2,.tensorflow.data.model.ModelProto.NodesEntry\x12\x0e\n\x06output\x18\x02 \x01(\x03\x12\x12\n\nid_counter\x18\x03 \x01(\x03\x12\x1e\n\x16collect_resource_usage\x18\x04 \x01(\x08\x12Q\n\x13optimization_params\x18\x05 \x01(\x0b24.tensorflow.data.model.ModelProto.OptimizationParams\x1a\xbf\x04\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08autotune\x18\x03 \x01(\x08\x12\x16\n\x0ebuffered_bytes\x18\x04 \x01(\x03\x12\x19\n\x11buffered_elements\x18\x05 \x01(\x03\x12\x16\n\x0ebytes_consumed\x18\x06 \x01(\x03\x12\x16\n\x0ebytes_produced\x18\x07 \x01(\x03\x12\x14\n\x0cnum_elements\x18\x08 \x01(\x03\x12\x17\n\x0fprocessing_time\x18\t \x01(\x03\x12\x16\n\x0erecord_metrics\x18\n \x01(\x08\x12D\n\nparameters\x18\x0b \x03(\x0b20.tensorflow.data.model.ModelProto.Node.Parameter\x12!\n\x19input_processing_time_sum\x18\x0c \x01(\x01\x12#\n\x1binput_processing_time_count\x18\r \x01(\x03\x12\x0e\n\x06inputs\x18\x0e \x03(\x03\x124\n\nnode_class\x18\x0f \x01(\x0e2 .tensorflow.data.model.NodeClass\x12\r\n\x05ratio\x18\x10 \x01(\x01\x12\x14\n\x0cmemory_ratio\x18\x11 \x01(\x01\x1ah\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x13\n\x0bstate_value\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\x0f\n\x07tunable\x18\x06 \x01(\x08\x1aT\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x125\n\x05value\x18\x02 \x01(\x0b2&.tensorflow.data.model.ModelProto.Node:\x028\x01\x1a\x93\x01\n\x12OptimizationParams\x12;\n\talgorithm\x18\x01 \x01(\x0e2(.tensorflow.data.model.AutotuneAlgorithm\x12\x12\n\ncpu_budget\x18\x02 \x01(\x03\x12\x12\n\nram_budget\x18\x03 \x01(\x03\x12\x18\n\x10model_input_time\x18\x04 \x01(\x01*\x83\x01\n\tNodeClass\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fINTERLEAVE_MANY\x10\x01\x12\x19\n\x15ASYNC_INTERLEAVE_MANY\x10\x02\x12\x0f\n\x0bKNOWN_RATIO\x10\x03\x12\x15\n\x11ASYNC_KNOWN_RATIO\x10\x04\x12\x11\n\rUNKNOWN_RATIO\x10\x05*9\n\x11AutotuneAlgorithm\x12\x0e\n\nHILL_CLIMB\x10\x00\x12\x14\n\x10GRADIENT_DESCENT\x10\x01BQZLgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/model_go_proto\xf8\x01\x01b\x06proto3')
_NODECLASS = _descriptor.EnumDescriptor(name='NodeClass', full_name='tensorflow.data.model.NodeClass', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INTERLEAVE_MANY', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ASYNC_INTERLEAVE_MANY', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='KNOWN_RATIO', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ASYNC_KNOWN_RATIO', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='UNKNOWN_RATIO', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1106, serialized_end=1237)
_sym_db.RegisterEnumDescriptor(_NODECLASS)
NodeClass = enum_type_wrapper.EnumTypeWrapper(_NODECLASS)
_AUTOTUNEALGORITHM = _descriptor.EnumDescriptor(name='AutotuneAlgorithm', full_name='tensorflow.data.model.AutotuneAlgorithm', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='HILL_CLIMB', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GRADIENT_DESCENT', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1239, serialized_end=1296)
_sym_db.RegisterEnumDescriptor(_AUTOTUNEALGORITHM)
AutotuneAlgorithm = enum_type_wrapper.EnumTypeWrapper(_AUTOTUNEALGORITHM)
UNKNOWN = 0
INTERLEAVE_MANY = 1
ASYNC_INTERLEAVE_MANY = 2
KNOWN_RATIO = 3
ASYNC_KNOWN_RATIO = 4
UNKNOWN_RATIO = 5
HILL_CLIMB = 0
GRADIENT_DESCENT = 1
_MODELPROTO_NODE_PARAMETER = _descriptor.Descriptor(name='Parameter', full_name='tensorflow.data.model.ModelProto.Node.Parameter', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.data.model.ModelProto.Node.Parameter.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.data.model.ModelProto.Node.Parameter.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='state_value', full_name='tensorflow.data.model.ModelProto.Node.Parameter.state_value', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min', full_name='tensorflow.data.model.ModelProto.Node.Parameter.min', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max', full_name='tensorflow.data.model.ModelProto.Node.Parameter.max', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tunable', full_name='tensorflow.data.model.ModelProto.Node.Parameter.tunable', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=763, serialized_end=867)
_MODELPROTO_NODE = _descriptor.Descriptor(name='Node', full_name='tensorflow.data.model.ModelProto.Node', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.data.model.ModelProto.Node.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.data.model.ModelProto.Node.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='autotune', full_name='tensorflow.data.model.ModelProto.Node.autotune', index=2, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buffered_bytes', full_name='tensorflow.data.model.ModelProto.Node.buffered_bytes', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buffered_elements', full_name='tensorflow.data.model.ModelProto.Node.buffered_elements', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_consumed', full_name='tensorflow.data.model.ModelProto.Node.bytes_consumed', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_produced', full_name='tensorflow.data.model.ModelProto.Node.bytes_produced', index=6, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_elements', full_name='tensorflow.data.model.ModelProto.Node.num_elements', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='processing_time', full_name='tensorflow.data.model.ModelProto.Node.processing_time', index=8, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='record_metrics', full_name='tensorflow.data.model.ModelProto.Node.record_metrics', index=9, number=10, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parameters', full_name='tensorflow.data.model.ModelProto.Node.parameters', index=10, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_processing_time_sum', full_name='tensorflow.data.model.ModelProto.Node.input_processing_time_sum', index=11, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_processing_time_count', full_name='tensorflow.data.model.ModelProto.Node.input_processing_time_count', index=12, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inputs', full_name='tensorflow.data.model.ModelProto.Node.inputs', index=13, number=14, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_class', full_name='tensorflow.data.model.ModelProto.Node.node_class', index=14, number=15, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ratio', full_name='tensorflow.data.model.ModelProto.Node.ratio', index=15, number=16, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_ratio', full_name='tensorflow.data.model.ModelProto.Node.memory_ratio', index=16, number=17, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_MODELPROTO_NODE_PARAMETER], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=292, serialized_end=867)
_MODELPROTO_NODESENTRY = _descriptor.Descriptor(name='NodesEntry', full_name='tensorflow.data.model.ModelProto.NodesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.data.model.ModelProto.NodesEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.data.model.ModelProto.NodesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=869, serialized_end=953)
_MODELPROTO_OPTIMIZATIONPARAMS = _descriptor.Descriptor(name='OptimizationParams', full_name='tensorflow.data.model.ModelProto.OptimizationParams', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='tensorflow.data.model.ModelProto.OptimizationParams.algorithm', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_budget', full_name='tensorflow.data.model.ModelProto.OptimizationParams.cpu_budget', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ram_budget', full_name='tensorflow.data.model.ModelProto.OptimizationParams.ram_budget', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_input_time', full_name='tensorflow.data.model.ModelProto.OptimizationParams.model_input_time', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=956, serialized_end=1103)
_MODELPROTO = _descriptor.Descriptor(name='ModelProto', full_name='tensorflow.data.model.ModelProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='nodes', full_name='tensorflow.data.model.ModelProto.nodes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output', full_name='tensorflow.data.model.ModelProto.output', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='id_counter', full_name='tensorflow.data.model.ModelProto.id_counter', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='collect_resource_usage', full_name='tensorflow.data.model.ModelProto.collect_resource_usage', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='optimization_params', full_name='tensorflow.data.model.ModelProto.optimization_params', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_MODELPROTO_NODE, _MODELPROTO_NODESENTRY, _MODELPROTO_OPTIMIZATIONPARAMS], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=65, serialized_end=1103)
_MODELPROTO_NODE_PARAMETER.containing_type = _MODELPROTO_NODE
_MODELPROTO_NODE.fields_by_name['parameters'].message_type = _MODELPROTO_NODE_PARAMETER
_MODELPROTO_NODE.fields_by_name['node_class'].enum_type = _NODECLASS
_MODELPROTO_NODE.containing_type = _MODELPROTO
_MODELPROTO_NODESENTRY.fields_by_name['value'].message_type = _MODELPROTO_NODE
_MODELPROTO_NODESENTRY.containing_type = _MODELPROTO
_MODELPROTO_OPTIMIZATIONPARAMS.fields_by_name['algorithm'].enum_type = _AUTOTUNEALGORITHM
_MODELPROTO_OPTIMIZATIONPARAMS.containing_type = _MODELPROTO
_MODELPROTO.fields_by_name['nodes'].message_type = _MODELPROTO_NODESENTRY
_MODELPROTO.fields_by_name['optimization_params'].message_type = _MODELPROTO_OPTIMIZATIONPARAMS
DESCRIPTOR.message_types_by_name['ModelProto'] = _MODELPROTO
DESCRIPTOR.enum_types_by_name['NodeClass'] = _NODECLASS
DESCRIPTOR.enum_types_by_name['AutotuneAlgorithm'] = _AUTOTUNEALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ModelProto = _reflection.GeneratedProtocolMessageType('ModelProto', (_message.Message,), {'Node': _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {'Parameter': _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {'DESCRIPTOR': _MODELPROTO_NODE_PARAMETER, '__module__': 'tensorflow.core.framework.model_pb2'}), 'DESCRIPTOR': _MODELPROTO_NODE, '__module__': 'tensorflow.core.framework.model_pb2'}), 'NodesEntry': _reflection.GeneratedProtocolMessageType('NodesEntry', (_message.Message,), {'DESCRIPTOR': _MODELPROTO_NODESENTRY, '__module__': 'tensorflow.core.framework.model_pb2'}), 'OptimizationParams': _reflection.GeneratedProtocolMessageType('OptimizationParams', (_message.Message,), {'DESCRIPTOR': _MODELPROTO_OPTIMIZATIONPARAMS, '__module__': 'tensorflow.core.framework.model_pb2'}), 'DESCRIPTOR': _MODELPROTO, '__module__': 'tensorflow.core.framework.model_pb2'})
_sym_db.RegisterMessage(ModelProto)
_sym_db.RegisterMessage(ModelProto.Node)
_sym_db.RegisterMessage(ModelProto.Node.Parameter)
_sym_db.RegisterMessage(ModelProto.NodesEntry)
_sym_db.RegisterMessage(ModelProto.OptimizationParams)
DESCRIPTOR._options = None
_MODELPROTO_NODESENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/lite/toco/logging/toco_conversion_log.proto', package='toco', syntax='proto2', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/lite/toco/logging/toco_conversion_log.proto\x12\x04toco"\xc9\x04\n\x11TocoConversionLog\x12\x0f\n\x07op_list\x18\x01 \x03(\t\x12=\n\x0cbuilt_in_ops\x18\x02 \x03(\x0b2\'.toco.TocoConversionLog.BuiltInOpsEntry\x12:\n\ncustom_ops\x18\x03 \x03(\x0b2&.toco.TocoConversionLog.CustomOpsEntry\x12:\n\nselect_ops\x18\x04 \x03(\x0b2&.toco.TocoConversionLog.SelectOpsEntry\x12\x15\n\rop_signatures\x18\x05 \x03(\t\x12\x1a\n\x12input_tensor_types\x18\x06 \x03(\t\x12\x1b\n\x13output_tensor_types\x18\x07 \x03(\t\x12\x19\n\x11log_generation_ts\x18\x08 \x01(\x03\x12\x12\n\nmodel_size\x18\t \x01(\x05\x12\x17\n\x0ftf_lite_version\x18\n \x01(\t\x12\x12\n\nos_version\x18\x0b \x01(\t\x12\x12\n\nmodel_hash\x18\x0c \x01(\t\x12\x15\n\rtoco_err_logs\x18\r \x01(\t\x1a1\n\x0fBuiltInOpsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x028\x01\x1a0\n\x0eCustomOpsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x028\x01\x1a0\n\x0eSelectOpsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x028\x01')
_TOCOCONVERSIONLOG_BUILTINOPSENTRY = _descriptor.Descriptor(name='BuiltInOpsEntry', full_name='toco.TocoConversionLog.BuiltInOpsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='toco.TocoConversionLog.BuiltInOpsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='toco.TocoConversionLog.BuiltInOpsEntry.value', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=501, serialized_end=550)
_TOCOCONVERSIONLOG_CUSTOMOPSENTRY = _descriptor.Descriptor(name='CustomOpsEntry', full_name='toco.TocoConversionLog.CustomOpsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='toco.TocoConversionLog.CustomOpsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='toco.TocoConversionLog.CustomOpsEntry.value', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=552, serialized_end=600)
_TOCOCONVERSIONLOG_SELECTOPSENTRY = _descriptor.Descriptor(name='SelectOpsEntry', full_name='toco.TocoConversionLog.SelectOpsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='toco.TocoConversionLog.SelectOpsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='toco.TocoConversionLog.SelectOpsEntry.value', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=602, serialized_end=650)
_TOCOCONVERSIONLOG = _descriptor.Descriptor(name='TocoConversionLog', full_name='toco.TocoConversionLog', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_list', full_name='toco.TocoConversionLog.op_list', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='built_in_ops', full_name='toco.TocoConversionLog.built_in_ops', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='custom_ops', full_name='toco.TocoConversionLog.custom_ops', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='select_ops', full_name='toco.TocoConversionLog.select_ops', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_signatures', full_name='toco.TocoConversionLog.op_signatures', index=4, number=5, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_tensor_types', full_name='toco.TocoConversionLog.input_tensor_types', index=5, number=6, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_tensor_types', full_name='toco.TocoConversionLog.output_tensor_types', index=6, number=7, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='log_generation_ts', full_name='toco.TocoConversionLog.log_generation_ts', index=7, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_size', full_name='toco.TocoConversionLog.model_size', index=8, number=9, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_lite_version', full_name='toco.TocoConversionLog.tf_lite_version', index=9, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='os_version', full_name='toco.TocoConversionLog.os_version', index=10, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_hash', full_name='toco.TocoConversionLog.model_hash', index=11, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='toco_err_logs', full_name='toco.TocoConversionLog.toco_err_logs', index=12, number=13, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TOCOCONVERSIONLOG_BUILTINOPSENTRY, _TOCOCONVERSIONLOG_CUSTOMOPSENTRY, _TOCOCONVERSIONLOG_SELECTOPSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=65, serialized_end=650)
_TOCOCONVERSIONLOG_BUILTINOPSENTRY.containing_type = _TOCOCONVERSIONLOG
_TOCOCONVERSIONLOG_CUSTOMOPSENTRY.containing_type = _TOCOCONVERSIONLOG
_TOCOCONVERSIONLOG_SELECTOPSENTRY.containing_type = _TOCOCONVERSIONLOG
_TOCOCONVERSIONLOG.fields_by_name['built_in_ops'].message_type = _TOCOCONVERSIONLOG_BUILTINOPSENTRY
_TOCOCONVERSIONLOG.fields_by_name['custom_ops'].message_type = _TOCOCONVERSIONLOG_CUSTOMOPSENTRY
_TOCOCONVERSIONLOG.fields_by_name['select_ops'].message_type = _TOCOCONVERSIONLOG_SELECTOPSENTRY
DESCRIPTOR.message_types_by_name['TocoConversionLog'] = _TOCOCONVERSIONLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TocoConversionLog = _reflection.GeneratedProtocolMessageType('TocoConversionLog', (_message.Message,), {'BuiltInOpsEntry': _reflection.GeneratedProtocolMessageType('BuiltInOpsEntry', (_message.Message,), {'DESCRIPTOR': _TOCOCONVERSIONLOG_BUILTINOPSENTRY, '__module__': 'tensorflow.lite.toco.logging.toco_conversion_log_pb2'}), 'CustomOpsEntry': _reflection.GeneratedProtocolMessageType('CustomOpsEntry', (_message.Message,), {'DESCRIPTOR': _TOCOCONVERSIONLOG_CUSTOMOPSENTRY, '__module__': 'tensorflow.lite.toco.logging.toco_conversion_log_pb2'}), 'SelectOpsEntry': _reflection.GeneratedProtocolMessageType('SelectOpsEntry', (_message.Message,), {'DESCRIPTOR': _TOCOCONVERSIONLOG_SELECTOPSENTRY, '__module__': 'tensorflow.lite.toco.logging.toco_conversion_log_pb2'}), 'DESCRIPTOR': _TOCOCONVERSIONLOG, '__module__': 'tensorflow.lite.toco.logging.toco_conversion_log_pb2'})
_sym_db.RegisterMessage(TocoConversionLog)
_sym_db.RegisterMessage(TocoConversionLog.BuiltInOpsEntry)
_sym_db.RegisterMessage(TocoConversionLog.CustomOpsEntry)
_sym_db.RegisterMessage(TocoConversionLog.SelectOpsEntry)
_TOCOCONVERSIONLOG_BUILTINOPSENTRY._options = None
_TOCOCONVERSIONLOG_CUSTOMOPSENTRY._options = None
_TOCOCONVERSIONLOG_SELECTOPSENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/critical_section.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x15CriticalSectionProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/protobuf/critical_section.proto\x12\ntensorflow"3\n\x12CriticalSectionDef\x12\x1d\n\x15critical_section_name\x18\x01 \x01(\t"j\n\x1bCriticalSectionExecutionDef\x12(\n execute_in_critical_section_name\x18\x01 \x01(\t\x12!\n\x19exclusive_resource_access\x18\x02 \x01(\x08B\x8d\x01\n\x18org.tensorflow.frameworkB\x15CriticalSectionProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_CRITICALSECTIONDEF = _descriptor.Descriptor(name='CriticalSectionDef', full_name='tensorflow.CriticalSectionDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='critical_section_name', full_name='tensorflow.CriticalSectionDef.critical_section_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=63, serialized_end=114)
_CRITICALSECTIONEXECUTIONDEF = _descriptor.Descriptor(name='CriticalSectionExecutionDef', full_name='tensorflow.CriticalSectionExecutionDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='execute_in_critical_section_name', full_name='tensorflow.CriticalSectionExecutionDef.execute_in_critical_section_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exclusive_resource_access', full_name='tensorflow.CriticalSectionExecutionDef.exclusive_resource_access', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=116, serialized_end=222)
DESCRIPTOR.message_types_by_name['CriticalSectionDef'] = _CRITICALSECTIONDEF
DESCRIPTOR.message_types_by_name['CriticalSectionExecutionDef'] = _CRITICALSECTIONEXECUTIONDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CriticalSectionDef = _reflection.GeneratedProtocolMessageType('CriticalSectionDef', (_message.Message,), {'DESCRIPTOR': _CRITICALSECTIONDEF, '__module__': 'tensorflow.core.protobuf.critical_section_pb2'})
_sym_db.RegisterMessage(CriticalSectionDef)
CriticalSectionExecutionDef = _reflection.GeneratedProtocolMessageType('CriticalSectionExecutionDef', (_message.Message,), {'DESCRIPTOR': _CRITICALSECTIONEXECUTIONDEF, '__module__': 'tensorflow.core.protobuf.critical_section_pb2'})
_sym_db.RegisterMessage(CriticalSectionExecutionDef)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/example/example_parser_configuration.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x16org.tensorflow.exampleB ExampleParserConfigurationProtosP\x01Zagithub.com/tensorflow/tensorflow/tensorflow/go/core/example/example_parser_configuration_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n:tensorflow/core/example/example_parser_configuration.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\xa3\x01\n\x12VarLenFeatureProto\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12!\n\x19values_output_tensor_name\x18\x02 \x01(\t\x12"\n\x1aindices_output_tensor_name\x18\x03 \x01(\t\x12!\n\x19shapes_output_tensor_name\x18\x04 \x01(\t"\xbb\x01\n\x14FixedLenFeatureProto\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12+\n\x05shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12.\n\rdefault_value\x18\x03 \x01(\x0b2\x17.tensorflow.TensorProto\x12!\n\x19values_output_tensor_name\x18\x04 \x01(\t"\x9a\x01\n\x14FeatureConfiguration\x12=\n\x11fixed_len_feature\x18\x01 \x01(\x0b2 .tensorflow.FixedLenFeatureProtoH\x00\x129\n\x0fvar_len_feature\x18\x02 \x01(\x0b2\x1e.tensorflow.VarLenFeatureProtoH\x00B\x08\n\x06config"\xbe\x01\n\x1aExampleParserConfiguration\x12K\n\x0bfeature_map\x18\x01 \x03(\x0b26.tensorflow.ExampleParserConfiguration.FeatureMapEntry\x1aS\n\x0fFeatureMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b2 .tensorflow.FeatureConfiguration:\x028\x01B\xa2\x01\n\x16org.tensorflow.exampleB ExampleParserConfigurationProtosP\x01Zagithub.com/tensorflow/tensorflow/tensorflow/go/core/example/example_parser_configuration_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_VARLENFEATUREPROTO = _descriptor.Descriptor(name='VarLenFeatureProto', full_name='tensorflow.VarLenFeatureProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.VarLenFeatureProto.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='values_output_tensor_name', full_name='tensorflow.VarLenFeatureProto.values_output_tensor_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='indices_output_tensor_name', full_name='tensorflow.VarLenFeatureProto.indices_output_tensor_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shapes_output_tensor_name', full_name='tensorflow.VarLenFeatureProto.shapes_output_tensor_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=200, serialized_end=363)
_FIXEDLENFEATUREPROTO = _descriptor.Descriptor(name='FixedLenFeatureProto', full_name='tensorflow.FixedLenFeatureProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.FixedLenFeatureProto.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.FixedLenFeatureProto.shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_value', full_name='tensorflow.FixedLenFeatureProto.default_value', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='values_output_tensor_name', full_name='tensorflow.FixedLenFeatureProto.values_output_tensor_name', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=366, serialized_end=553)
_FEATURECONFIGURATION = _descriptor.Descriptor(name='FeatureConfiguration', full_name='tensorflow.FeatureConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='fixed_len_feature', full_name='tensorflow.FeatureConfiguration.fixed_len_feature', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='var_len_feature', full_name='tensorflow.FeatureConfiguration.var_len_feature', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='config', full_name='tensorflow.FeatureConfiguration.config', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=556, serialized_end=710)
_EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY = _descriptor.Descriptor(name='FeatureMapEntry', full_name='tensorflow.ExampleParserConfiguration.FeatureMapEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.ExampleParserConfiguration.FeatureMapEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.ExampleParserConfiguration.FeatureMapEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=820, serialized_end=903)
_EXAMPLEPARSERCONFIGURATION = _descriptor.Descriptor(name='ExampleParserConfiguration', full_name='tensorflow.ExampleParserConfiguration', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_map', full_name='tensorflow.ExampleParserConfiguration.feature_map', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=713, serialized_end=903)
_VARLENFEATUREPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_FIXEDLENFEATUREPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_FIXEDLENFEATUREPROTO.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_FIXEDLENFEATUREPROTO.fields_by_name['default_value'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_FEATURECONFIGURATION.fields_by_name['fixed_len_feature'].message_type = _FIXEDLENFEATUREPROTO
_FEATURECONFIGURATION.fields_by_name['var_len_feature'].message_type = _VARLENFEATUREPROTO
_FEATURECONFIGURATION.oneofs_by_name['config'].fields.append(_FEATURECONFIGURATION.fields_by_name['fixed_len_feature'])
_FEATURECONFIGURATION.fields_by_name['fixed_len_feature'].containing_oneof = _FEATURECONFIGURATION.oneofs_by_name['config']
_FEATURECONFIGURATION.oneofs_by_name['config'].fields.append(_FEATURECONFIGURATION.fields_by_name['var_len_feature'])
_FEATURECONFIGURATION.fields_by_name['var_len_feature'].containing_oneof = _FEATURECONFIGURATION.oneofs_by_name['config']
_EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY.fields_by_name['value'].message_type = _FEATURECONFIGURATION
_EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY.containing_type = _EXAMPLEPARSERCONFIGURATION
_EXAMPLEPARSERCONFIGURATION.fields_by_name['feature_map'].message_type = _EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY
DESCRIPTOR.message_types_by_name['VarLenFeatureProto'] = _VARLENFEATUREPROTO
DESCRIPTOR.message_types_by_name['FixedLenFeatureProto'] = _FIXEDLENFEATUREPROTO
DESCRIPTOR.message_types_by_name['FeatureConfiguration'] = _FEATURECONFIGURATION
DESCRIPTOR.message_types_by_name['ExampleParserConfiguration'] = _EXAMPLEPARSERCONFIGURATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
VarLenFeatureProto = _reflection.GeneratedProtocolMessageType('VarLenFeatureProto', (_message.Message,), {'DESCRIPTOR': _VARLENFEATUREPROTO, '__module__': 'tensorflow.core.example.example_parser_configuration_pb2'})
_sym_db.RegisterMessage(VarLenFeatureProto)
FixedLenFeatureProto = _reflection.GeneratedProtocolMessageType('FixedLenFeatureProto', (_message.Message,), {'DESCRIPTOR': _FIXEDLENFEATUREPROTO, '__module__': 'tensorflow.core.example.example_parser_configuration_pb2'})
_sym_db.RegisterMessage(FixedLenFeatureProto)
FeatureConfiguration = _reflection.GeneratedProtocolMessageType('FeatureConfiguration', (_message.Message,), {'DESCRIPTOR': _FEATURECONFIGURATION, '__module__': 'tensorflow.core.example.example_parser_configuration_pb2'})
_sym_db.RegisterMessage(FeatureConfiguration)
ExampleParserConfiguration = _reflection.GeneratedProtocolMessageType('ExampleParserConfiguration', (_message.Message,), {'FeatureMapEntry': _reflection.GeneratedProtocolMessageType('FeatureMapEntry', (_message.Message,), {'DESCRIPTOR': _EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY, '__module__': 'tensorflow.core.example.example_parser_configuration_pb2'}), 'DESCRIPTOR': _EXAMPLEPARSERCONFIGURATION, '__module__': 'tensorflow.core.example.example_parser_configuration_pb2'})
_sym_db.RegisterMessage(ExampleParserConfiguration)
_sym_db.RegisterMessage(ExampleParserConfiguration.FeatureMapEntry)
DESCRIPTOR._options = None
_EXAMPLEPARSERCONFIGURATION_FEATUREMAPENTRY._options = None



from . import errors
from . import core
from . import file_system
from . import iterator
from . import coding
from . import strings
from enum import Enum
from typing import NamedTuple
import numpy as np

# kTableMagicNumber was picked by running
#    echo http://code.google.com/p/leveldb/ | sha1sum
# and taking the leading 64 bits.
kTableMagicNumber = 0xdb4775248b80fb57

# 1-byte type + 32-bit crc
kBlockTrailerSize = 5


# DB contents are stored in a set of blocks, each of which holds a
# sequence of key,value pairs.  Each block may be compressed before
# being stored in a file.  The following enum describes which
# compression method (if any) is used to compress a block.
class CompressionType(Enum):
  # NOTE: do not change the values of existing entries, as these are
  # part of the persistent format on disk.
  kNoCompression = 0x0
  kSnappyCompression = 0x1


class BlockHandle:
  kMaxEncodedLength = 10 + 10

  def __init__(self):
    self._offset = 0
    self._size = 0

  @property
  def offset(self) -> int:
    return self._offset

  def set_offset(self, value: int):
    self._offset = value

  @property
  def size(self) -> int:
    return self._size

  def set_size(self, value: int):
    self._size = value

  def encode_to(self):
    # // Sanity check that all fields have been set
    # assert(offset_ != ~static_cast<uint64>(0));
    assert self._offset != ~np.uint64(0)
    # assert(size_ != ~static_cast<uint64>(0));
    assert self._size != ~np.uint64(0)
    # core::PutVarint64(dst, offset_);
    dst = coding.encode_varint64(self._offset)
    # core::PutVarint64(dst, size_);
    dst = dst + coding.encode_varint64(self._size)
    return dst

  def decode_from(self, input: core.StringPiece):
    ok, self._offset = core.get_varint_64(input)
    if ok:
      ok, self._size = core.get_varint_64(input)
      if ok:
        return
    raise errors.DataLoss("bad block handle")


class Footer:
  kEncodedLength = 2 * BlockHandle.kMaxEncodedLength + 8

  def __init__(self):
    self._metaindex_handle = BlockHandle()
    self._index_handle = BlockHandle()

  @property
  def index_handle(self) -> BlockHandle:
    return self._index_handle

  def set_index_handle(self, handle: BlockHandle):
    self._index_handle = handle

  @property
  def metaindex_handle(self) -> BlockHandle:
    return self._metaindex_handle

  def set_metaindex_handle(self, handle: BlockHandle):
    self._metaindex_handle = handle

  def encode_to(self):
    ##ifndef NDEBUG
    # const size_t original_size = dst->size();
    ##endif
    original_size = 0
    # metaindex_handle_.EncodeTo(dst);
    dst = self._metaindex_handle.encode_to()
    # index_handle_.EncodeTo(dst);
    dst = dst + self._index_handle.encode_to()
    # dst->resize(2 * BlockHandle::kMaxEncodedLength);  // Padding
    strings.resize(dst, 2 * BlockHandle.kMaxEncodedLength)  # Padding
    # core::PutFixed32(dst, static_cast<uint32>(kTableMagicNumber & 0xffffffffu));
    coding.put_fixed32(dst, kTableMagicNumber & 0xffffffff)
    # core::PutFixed32(dst, static_cast<uint32>(kTableMagicNumber >> 32));
    coding.put_fixed32(dst, kTableMagicNumber >> 32)
    # assert(dst->size() == original_size + kEncodedLength);
    assert len(dst) == original_size + self.kEncodedLength
    return dst

  def decode_from(self, input: core.StringPiece):
    magic = core.decode_fixed_64(input.slice(), Footer.kEncodedLength - 8)
    if magic != kTableMagicNumber:
      raise errors.DataLoss("not an sstable (bad magic number)");
    self._metaindex_handle.decode_from(input)
    self._index_handle.decode_from(input)
    # We skip over any leftover data (just padding for now) in "input"
    #end = Footer.kEncodedLength


class BlockContents:
  data: core.StringPiece # Actual contents of data
  cacheable: bool        # True iff data can be cached
  heap_allocated: bool   # True iff caller should delete[] data.data()


def read_block(file: file_system.RandomAccessFile, handle: BlockHandle) -> BlockContents:
  result = BlockContents()
  # result.data = core.StringPiece(b'')
  # result.cacheable = False
  # result.heap_allocated = False
  n = handle.size
  contents = errors.raise_if_error(file.read(handle.offset, n + kBlockTrailerSize))
  if contents.size() != n + kBlockTrailerSize:
    raise errors.DataLoss("truncated block read")

  # // Check the crc of the type and the block contents
  # const char* data = contents.data();  // Pointer to where Read put the data
  # // This checksum verification is optional.  We leave it on for now
  # const bool verify_checksum = true;
  # if (verify_checksum) {
  #   const uint32 crc = crc32c::Unmask(core::DecodeFixed32(data + n + 1));
  #   const uint32 actual = crc32c::Value(data, n + 1);
  #   if (actual != crc) {
  #     delete[] buf;
  #     s = errors::DataLoss("block checksum mismatch");
  #     return s;
  #   }
  # }
  data = contents.slice()
  if data[n] == CompressionType.kNoCompression.value:
    result.data = core.StringPiece(data, n)
    result.cacheable = False
    result.heap_allocated = False
  else:
    raise NotImplementedError()
  return result


def decode_entry(data: bytes, p, limit):
  if limit - p < 3:
    return None
  shared = data[p + 0]
  non_shared = data[p + 1]
  value_length = data[p + 2]
  if (shared | non_shared | value_length) < 128:
    # Fast path: all three values are encoded in one byte each
    p += 3
  else:
    p, shared = core.get_varint_32_ptr(data, p, limit)
    if p is not None:
      p, non_shared = core.get_varint_32_ptr(data, p, limit)
    if p is not None:
      p, value_length = core.get_varint_32_ptr(data, p, limit)
    # if ((p = core::GetVarint32Ptr(p, limit, shared)) == nullptr) return nullptr;
    # if ((p = core::GetVarint32Ptr(p, limit, non_shared)) == nullptr)
    #   return nullptr;
    # if ((p = core::GetVarint32Ptr(p, limit, value_length)) == nullptr)
    #   return nullptr;
  return p, shared, non_shared, value_length


class Block:
  class Iter(iterator.Iterator):
    def __init__(self, data, restarts: int, num_restarts: int):
      self._data = data
      self._restarts = restarts
      self._num_restarts = num_restarts
      self._current = self._restarts
      self._restart_index = self._num_restarts
      self._key = b""
      self._value = core.StringPiece()
      self._status = None
      assert self._num_restarts > 0

    def next_entry_offset(self) -> int:
      # return (value_.data() + value_.size()) - data_;
      return self._value._offset + self._value.size()

    def get_restart_point(self, index: int) -> int:
      assert index < self._num_restarts
      # return core::DecodeFixed32(data_ + restarts_ + index * sizeof(uint32));
      return core.decode_fixed_32(self._data, self._restarts + index * 4)

    def seek_to_restart_point(self, index: int):
      self._Key = b""
      self._restart_index = index
      # current_ will be fixed by ParseNextKey()

      # ParseNextKey() starts at the end of value_, so set value_ accordingly
      offset = self.get_restart_point(index)
      self._value = core.StringPiece(self._data, 0, offset)

    def status(self):
      if self._status is not None:
        raise self._status

    def valid(self) -> bool:
      return self._current < self._restarts

    def key(self) -> core.StringPiece:
      assert self.valid()
      return core.StringPiece(self._key)

    def value(self) -> core.StringPiece:
      assert self.valid()
      return self._value

    def next(self):
      assert self.valid()
      self.parse_next_key()

    def seek(self, target: core.StringPiece):
      # Binary search in restart array to find the last restart point
      # with a key < target
      raise NotImplementedError()

    def seek_to_first(self):
      self.seek_to_restart_point(0)
      self.parse_next_key()

    def corruption_error(self):
      breakpoint()
      self._current = self._restarts
      self._restart_index = self._num_restarts
      self._status = errors.DataLoss("bad entry in block")
      self._key = b''
      self._value = core.StringPiece()

    def parse_next_key(self) -> bool:
      self._current = self.next_entry_offset()
      p = self._current
      limit = self._restarts  # Restarts come right after data
      if p >= limit:
        # No more entries to return.  Mark as invalid.
        self._current = self._restarts
        self._restart_index = self._num_restarts
        return False
      # Decode next entry
      p, shared, non_shared, value_length = decode_entry(self._data, p, limit)
      # breakpoint()
      if p is None:
        self.corruption_error()
        return False
      elif len(self._key) < shared:
        self.corruption_error()
        return False
      else:
        # key_.resize(shared);
        if len(self._key) < shared:
          self._key = b' ' * shared
        elif len(self._key) > shared:
          self._key = self._key[0:shared]
        # key_.append(p, non_shared)
        self._key += self._data[p:p + non_shared]
        self._value = core.StringPiece(self._data, value_length, p + non_shared)
        while self._restart_index + 1 < self._num_restarts and \
                self.get_restart_point(self._restart_index + 1) < self._current:
          self._restart_index += 1
        return True


  def __init__(self, contents: BlockContents):
    self._data = contents.data.slice()
    self._size = contents.data.size()
    self._owned = contents.heap_allocated
    if self._size < 4:
      breakpoint()
      self._size = 0 # Error marker
    else:
      max_restarts_allowed = (self._size - 4) // 4
      if self.num_restarts() > max_restarts_allowed:
        # The size is too small for NumRestarts()
        breakpoint()
        self._size = 0
      else:
        self._restart_offset = self._size - (1 + self.num_restarts()) * 4

  def num_restarts(self):
     return core.decode_fixed_32(self._data, self._size - 4)

  def new_iterator(self) -> iterator.Iterator:
    if self._size < 4:
      return iterator.new_error_iterator(errors.DataLoss("bad block contents"))
    num_restarts = self.num_restarts()
    if num_restarts <= 0:
      return iterator.new_empty_iterator()
    else:
      return Block.Iter(self._data, self._restart_offset, num_restarts)


class Table:
  class Rep(NamedTuple):
    file: file_system.RandomAccessFile
    metaindex_handle: BlockHandle
    index_block: Block

  def __init__(self, rep: Rep):
    self._rep = rep

  @classmethod
  def open(cls, file: file_system.RandomAccessFile, size: int):
    if size < Footer.kEncodedLength:
      raise errors.DataLoss("file is too short to be an sstable")
    footer_input = errors.raise_if_error(file.read(size - Footer.kEncodedLength, Footer.kEncodedLength))
    footer = Footer()
    footer.decode_from(footer_input)

    contents: BlockContents = read_block(file, footer.index_handle)
    # We've successfully read the footer and the index block: we're
    # ready to serve requests.
    index_block = Block(contents)

    rep = Table.Rep(file, footer.metaindex_handle, index_block)
    return cls(rep)
    



from dataclasses import dataclass

@dataclass
class FileStatistics:
  # The length of the file or -1 if finding file length is not supported.
  length: int = -1
  # The last modified time in nanoseconds.
  mtime_nsec: int = 0
  # True if the file is a directory, otherwise false.
  is_directory: bool = False



from . import core
from . import strings
from . import platform

from typing import Tuple

Char = strings.Scanner.CharClass

kPathSep = b"/"

def join_path(*paths) -> bytes:
  result = b''
  for path in paths:
    path = core.string_view(path)
    if path.empty():
      continue

    if len(result) <= 0:
      result = path.slice()
      continue
    
    if is_absolute_path(path):
      path = path.substr(1)

    if result[-1] == kPathSep[0]:
      result += path.slice()
    else:
      result += kPathSep
      result += path.slice()
  return result

def split_path(uri) -> Tuple[core.StringPiece, core.StringPiece]:
  """Return the parts of the URI, split on the final "/" in the path. If there is
  no "/" in the path, the first part of the output is the scheme and host, and
  the second is the path. If the only "/" in the path is the first character,
  it is included in the first part of the output."""
  uri = core.string_view(uri)
  scheme, host, path = parse_uri(uri)
  pos = path.rfind('/')
  if platform.is_windows_platform():
    if pos == core.StringPiece.npos:
      pos = path.rfind('\\')
  # Handle the case with no '/' in 'path'.
  if pos == core.StringPiece.npos:
    return (core.StringPiece(uri.begin(), host.end() - uri.begin()),
            path)
  # Handle the case with a single leading '/' in 'path'.
  if pos == 0:
    return (core.StringPiece(uri.begin(), path.begin() + 1 - uri.begin()),
            core.StringPiece(path.data() + 1, path.size() - 1))

  return (core.StringPiece(uri.begin(), path.begin() + pos - uri.begin()),
          core.StringPiece(path.data() + pos + 1, path.size() - (pos + 1)))

def split_basename(path) -> Tuple[core.StringPiece, core.StringPiece]:
  """Return the parts of the basename of path, split on the final ".".
  If there is no "." in the basename or "." is the final character in the
  basename, the second value will be empty."""
  path = basename(path)
  pos = path.rfind('.')
  if pos == core.StringPiece.npos:
    return (path,
            core.StringPiece(path.data() + path.size(), 0))
  return (core.StringPiece(path.data(), pos),
          core.StringPiece(path.data() + pos + 1, path.size() - (pos + 1)))

def is_absolute_path(path) -> bool:
  path = core.string_view(path)
  return not path.empty() and path[0] == strings.Ascii.SLASH

def dirname(path) -> core.StringPiece:
  return split_path(path)[0]

def basename(path) -> core.StringPiece:
  return split_path(path)[1]

def extension(path) -> core.StringPiece:
  return split_basename(path)[1]

def clean_path(path) -> core.StringPiece:
  raise NotImplementedError()

def parse_uri(remaining) -> Tuple[core.StringPiece, core.StringPiece, core.StringPiece]:
  remaining = core.string_view(remaining)
  scheme = core.string_view()
  host = core.string_view()
  path = core.string_view()
  # 0. Parse scheme
  # Make sure scheme matches [a-zA-Z][0-9a-zA-Z.]*
  # TODO(keveman): Allow "+" and "-" in the scheme.
  # Keep URI pattern in TensorBoard's `_parse_event_files_spec` updated
  # accordingly
  if not strings.Scanner(remaining) \
          .one(Char.LETTER) \
          .many(Char.LETTER_DIGIT_DOT) \
          .stop_capture() \
          .one_literal("://") \
          .get_result(remaining, scheme):
    # If there's no scheme, assume the entire string is a path.
    scheme.set(core.StringPiece(remaining.begin(), 0))
    host.set(core.StringPiece(remaining.begin(), 0))
    path.set(remaining)
    return scheme, host, path

  # 1. Parse host
  if not strings.Scanner(remaining) \
          .scan_until(strings.Ascii.SLASH) \
          .get_result(remaining, host):
    # No path, so the rest of the URI is the host
    host.set(remaining)
    path.set(core.StringPiece(remaining.begin(), 0))
    return scheme, host, path

  # 2. The rest is the path
  path.set(remaining)
  return scheme, host, path


def create_uri(scheme, host, path) -> core.StringPiece:
  scheme = core.string_view(scheme)
  host = core.string_view(host)
  path = core.string_view(path)
  if scheme.empty():
    return path
  return core.StringPiece(scheme.bytes() + b"://" + host.bytes() + path.bytes())
